@@ -3,8 +3,10 @@ use super::{
     DrawableComponent,
 };
 use crate::{
+    components::dialog_paragraph,
     queue::{InternalEvent, NeedsUpdate, Queue},
     strings, ui,
+    ui::style::Theme,
 };
 use asyncgit::{sync, CWD};
 use crossterm::event::{Event, KeyCode};
@@ -14,9 +16,9 @@ use strings::commands;
 use sync::HookResult;
 use tui::{
     backend::Backend,
-    layout::{Alignment, Rect},
-    style::{Color, Style},
-    widgets::{Block, Borders, Clear, Paragraph, Text},
+    layout::Rect,
+    style::Style,
+    widgets::{Clear, Text},
     Frame,
 };
 
@@ -24,6 +26,7 @@ pub struct CommitComponent {
     msg: String,
     visible: bool,
     queue: Queue,
+    theme: Theme,
 }
 
 impl DrawableComponent for CommitComponent {
@@ -32,22 +35,19 @@ impl DrawableComponent for CommitComponent {
             let txt = if self.msg.is_empty() {
                 [Text::Styled(
                     Cow::from(strings::COMMIT_MSG),
-                    Style::default().fg(Color::DarkGray),
+                    self.theme.text(false, false),
                 )]
             } else {
-                [Text::Raw(Cow::from(self.msg.clone()))]
+                [Text::Styled(
+                    Cow::from(self.msg.clone()),
+                    Style::default(),
+                )]
             };
 
             let area = ui::centered_rect(60, 20, f.size());
             f.render_widget(Clear, area);
             f.render_widget(
-                Paragraph::new(txt.iter())
-                    .block(
-                        Block::default()
-                            .title(strings::COMMIT_TITLE)
-                            .borders(Borders::ALL),
-                    )
-                    .alignment(Alignment::Left),
+                dialog_paragraph(strings::COMMIT_TITLE, txt.iter()),
                 area,
             );
         }
@@ -112,11 +112,12 @@ impl Component for CommitComponent {
 
 impl CommitComponent {
     ///
-    pub fn new(queue: Queue) -> Self {
+    pub fn new(queue: Queue, theme: &Theme) -> Self {
         Self {
             queue,
             msg: String::default(),
             visible: false,
+            theme: *theme,
         }
     }
 
@@ -126,7 +127,7 @@ impl CommitComponent {
         {
             error!("commit-msg hook error: {}", e);
             self.queue.borrow_mut().push_back(
-                InternalEvent::ShowMsg(format!(
+                InternalEvent::ShowErrorMsg(format!(
                     "commit-msg hook error:\n{}",
                     e
                 )),
@@ -134,13 +135,23 @@ impl CommitComponent {
             return;
         }
 
-        sync::commit(CWD, &self.msg).unwrap();
+        if let Err(e) = sync::commit(CWD, &self.msg) {
+            error!("commit error: {}", &e);
+            self.queue.borrow_mut().push_back(
+                InternalEvent::ShowErrorMsg(format!(
+                    "commit failed:\n{}",
+                    &e
+                )),
+            );
+            return;
+        }
+
         if let HookResult::NotOk(e) =
             sync::hooks_post_commit(CWD).unwrap()
         {
             error!("post-commit hook error: {}", e);
             self.queue.borrow_mut().push_back(
-                InternalEvent::ShowMsg(format!(
+                InternalEvent::ShowErrorMsg(format!(
                     "post-commit hook error:\n{}",
                     e
                 )),
