@@ -1,6 +1,3 @@
-use crossterm::event::Event;
-use tui::{backend::Backend, layout::Rect, Frame};
-
 mod changes;
 mod command;
 mod commit;
@@ -19,6 +16,15 @@ pub use help::HelpComponent;
 pub use msg::MsgComponent;
 pub use reset::ResetComponent;
 
+use crossterm::event::Event;
+use tui::{
+    backend::Backend,
+    layout::Alignment,
+    layout::Rect,
+    widgets::{Block, Borders, Paragraph, Text},
+    Frame,
+};
+
 /// creates accessors for a list of components
 ///
 /// allows generating code to make sure
@@ -114,3 +120,15 @@ pub trait Component {
     ///
     fn show(&mut self) {}
 }
+
+fn dialog_paragraph<'a, 't, T>(
+    title: &'a str,
+    content: T,
+) -> Paragraph<'a, 't, T>
+where
+    T: Iterator<Item = &'t Text<'t>>,
+{
+    Paragraph::new(content)
+        .block(Block::default().title(title).borders(Borders::ALL))
+        .alignment(Alignment::Left)
+}
