@@ -12,32 +12,35 @@ use tui::{
     widgets::{Block, Borders, Clear, Paragraph, Text},
     Frame,
 };
+use ui::style::Theme;
 
-#[derive(Default)]
 pub struct MsgComponent {
     msg: String,
     visible: bool,
+    theme: Theme,
 }
 
 impl DrawableComponent for MsgComponent {
     fn draw<B: Backend>(&mut self, f: &mut Frame<B>, _rect: Rect) {
-        if self.visible {
-            let txt = vec![Text::Raw(Cow::from(self.msg.as_str()))];
-
-            let area = ui::centered_rect_absolute(65, 25, f.size());
-            f.render_widget(Clear, area);
-            f.render_widget(
-                Paragraph::new(txt.iter())
-                    .block(
-                        Block::default()
-                            .title(strings::MSG_TITLE)
-                            .borders(Borders::ALL),
-                    )
-                    .wrap(true)
-                    .alignment(Alignment::Left),
-                area,
-            );
+        if !self.visible {
+            return;
         }
+        let txt = vec![Text::Raw(Cow::from(self.msg.as_str()))];
+
+        let area = ui::centered_rect_absolute(65, 25, f.size());
+        f.render_widget(Clear, area);
+        f.render_widget(
+            Paragraph::new(txt.iter())
+                .block(
+                    Block::default()
+                        .title(strings::MSG_TITLE_ERROR)
+                        .title_style(self.theme.text_danger())
+                        .borders(Borders::ALL),
+                )
+                .alignment(Alignment::Left)
+                .wrap(true),
+            area,
+        );
     }
 }
 
@@ -84,6 +87,13 @@ impl Component for MsgComponent {
 }
 
 impl MsgComponent {
+    pub fn new(theme: &Theme) -> Self {
+        Self {
+            msg: String::new(),
+            visible: false,
+            theme: *theme,
+        }
+    }
     ///
     pub fn show_msg(&mut self, msg: &str) {
         self.msg = msg.to_string();
