@@ -25,7 +25,6 @@ use crossterm::{
     },
     ExecutableCommand, Result,
 };
-use io::Write;
 use log::error;
 use scopeguard::defer;
 use scopetime::scope_time;
@@ -34,7 +33,9 @@ use spinner::Spinner;
 use std::{
     env, fs,
     fs::File,
-    io, panic,
+    io::{self, Write},
+    panic,
+    path::PathBuf,
     time::{Duration, Instant},
 };
 use tui::{
@@ -175,12 +176,18 @@ fn start_terminal<W: Write>(
     Ok(terminal)
 }
 
+#[must_use]
+pub fn get_app_config_path() -> PathBuf {
+    let mut path = dirs::cache_dir().unwrap();
+    path.push("gitui");
+    fs::create_dir_all(&path).unwrap();
+    path
+}
+
 fn setup_logging() {
     if env::var("GITUI_LOGGING").is_ok() {
-        let mut path = dirs::cache_dir().unwrap();
-        path.push("gitui");
+        let mut path = get_app_config_path();
         path.push("gitui.log");
-        fs::create_dir_all(path.parent().unwrap()).unwrap();
 
         let _ = WriteLogger::init(
             LevelFilter::Trace,
