@@ -7,6 +7,8 @@ use crate::{
     },
     keys,
     strings::commands,
+    ui::calc_scroll_top,
+    ui::style::Theme,
 };
 use asyncgit::{sync, AsyncLog, AsyncNotification, CWD};
 use crossbeam_channel::Sender;
@@ -16,38 +18,17 @@ use sync::Tags;
 use tui::{
     backend::Backend,
     layout::{Alignment, Rect},
-    style::{Color, Style},
     widgets::{Block, Borders, Paragraph, Text},
     Frame,
 };
 use utils::{ItemBatch, LogEntry};
 
-const COLOR_SELECTION_BG: Color = Color::Blue;
-
-const STYLE_TAG: Style = Style::new().fg(Color::Yellow);
-const STYLE_HASH: Style = Style::new().fg(Color::Magenta);
-const STYLE_TIME: Style = Style::new().fg(Color::Blue);
-const STYLE_AUTHOR: Style = Style::new().fg(Color::Green);
-const STYLE_MSG: Style = Style::new().fg(Color::Reset);
-
-const STYLE_TAG_SELECTED: Style =
-    Style::new().fg(Color::Yellow).bg(COLOR_SELECTION_BG);
-const STYLE_HASH_SELECTED: Style =
-    Style::new().fg(Color::Magenta).bg(COLOR_SELECTION_BG);
-const STYLE_TIME_SELECTED: Style =
-    Style::new().fg(Color::White).bg(COLOR_SELECTION_BG);
-const STYLE_AUTHOR_SELECTED: Style =
-    Style::new().fg(Color::Green).bg(COLOR_SELECTION_BG);
-const STYLE_MSG_SELECTED: Style =
-    Style::new().fg(Color::Reset).bg(COLOR_SELECTION_BG);
-
 static ELEMENTS_PER_LINE: usize = 10;
 static SLICE_SIZE: usize = 1200;
-
 ///
 pub struct Revlog {
     selection: usize,
-    selection_max: usize,
+    count_total: usize,
     items: ItemBatch,
     git_log: AsyncLog,
     visible: bool,
@@ -55,21 +36,28 @@ pub struct Revlog {
     scroll_state: (Instant, f32),
     tags: Tags,
     current_size: (u16, u16),
+    scroll_top: usize,
+    theme: Theme,
 }
 
 impl Revlog {
     ///
-    pub fn new(sender: &Sender<AsyncNotification>) -> Self {
+    pub fn new(
+        sender: &Sender<AsyncNotification>,
+        theme: &Theme,
+    ) -> Self {
         Self {
             items: ItemBatch::default(),
             git_log: AsyncLog::new(sender.clone()),
             selection: 0,
-            selection_max: 0,
+            count_total: 0,
             visible: false,
             first_open_done: false,
             scroll_state: (Instant::now(), 0_f32),
             tags: Tags::new(),
             current_size: (0, 0),
+            scroll_top: 0,
+            theme: *theme,
         }
     }
 
@@ -78,12 +66,16 @@ impl Revlog {
         self.git_log.is_pending()
     }
 
+    fn selection_max(&self) -> usize {
+        self.count_total.saturating_sub(1)
+    }
+
     ///
     pub fn update(&mut self) {
-        self.selection_max =
-            self.git_log.count().unwrap().saturating_sub(1);
+        self.count_total = self.git_log.count().unwrap();
 
-        if self.items.needs_data(self.selection, self.selection_max) {
+        if self.items.needs_data(self.selection, self.selection_max())
+        {
             self.fetch_commits();
         }
 
@@ -131,10 +123,11 @@ impl Revlog {
                 self.selection.saturating_add(page_offset)
             }
             ScrollType::Home => 0,
-            ScrollType::End => self.selection_max,
+            ScrollType::End => self.selection_max(),
         };
 
-        self.selection = cmp::min(self.selection, self.selection_max);
+        self.selection =
+            cmp::min(self.selection, self.selection_max());
 
         self.update();
     }
@@ -168,44 +161,28 @@ impl Revlog {
         selected: bool,
         txt: &mut Vec<Text<'a>>,
         tags: Option<String>,
+        theme: &Theme,
     ) {
         let count_before = txt.len();
+        txt.reserve(ELEMENTS_PER_LINE);
 
         let splitter_txt = Cow::from(" ");
-        let splitter = if selected {
-            Text::Styled(
-                splitter_txt,
-                Style::new().bg(COLOR_SELECTION_BG),
-            )
-        } else {
-            Text::Raw(splitter_txt)
-        };
+        let splitter =
+            Text::Styled(splitter_txt, theme.text(true, selected));
 
         txt.push(Text::Styled(
             Cow::from(&e.hash[0..7]),
-            if selected {
-                STYLE_HASH_SELECTED
-            } else {
-                STYLE_HASH
-            },
+            theme.commit_hash(selected),
         ));
         txt.push(splitter.clone());
         txt.push(Text::Styled(
             Cow::from(e.time.as_str()),
-            if selected {
-                STYLE_TIME_SELECTED
-            } else {
-                STYLE_TIME
-            },
+            theme.commit_time(selected),
         ));
         txt.push(splitter.clone());
         txt.push(Text::Styled(
             Cow::from(e.author.as_str()),
-            if selected {
-                STYLE_AUTHOR_SELECTED
-            } else {
-                STYLE_AUTHOR
-            },
+            theme.commit_author(selected),
         ));
         txt.push(splitter.clone());
         txt.push(Text::Styled(
@@ -214,25 +191,44 @@ impl Revlog {
             } else {
                 String::from("")
             }),
-            if selected {
-                STYLE_TAG_SELECTED
-            } else {
-                STYLE_TAG
-            },
+            theme.tab(true).bg(theme.text(true, selected).bg),
         ));
         txt.push(splitter);
         txt.push(Text::Styled(
             Cow::from(e.msg.as_str()),
-            if selected {
-                STYLE_MSG_SELECTED
-            } else {
-                STYLE_MSG
-            },
+            theme.text(true, selected),
         ));
         txt.push(Text::Raw(Cow::from("\n")));
 
         assert_eq!(txt.len() - count_before, ELEMENTS_PER_LINE);
     }
+
+    fn get_text(&self) -> Vec<Text> {
+        let selection = self.relative_selection();
+
+        let mut txt = Vec::new();
+
+        for (idx, e) in self.items.items.iter().enumerate() {
+            let tag = if let Some(tags) = self.tags.get(&e.hash) {
+                Some(tags.join(" "))
+            } else {
+                None
+            };
+            Self::add_entry(
+                e,
+                idx == selection,
+                &mut txt,
+                tag,
+                &self.theme,
+            );
+        }
+
+        txt
+    }
+
+    fn relative_selection(&self) -> usize {
+        self.selection.saturating_sub(self.items.index_offset)
+    }
 }
 
 impl DrawableComponent for Revlog {
@@ -242,32 +238,27 @@ impl DrawableComponent for Revlog {
             area.height.saturating_sub(2),
         );
 
-        let height = area.height as usize;
-        let selection =
-            self.selection.saturating_sub(self.items.index_offset);
-        let height_d2 = height as usize / 2;
-        let min = selection.saturating_sub(height_d2);
+        let height_in_lines = self.current_size.1 as usize;
+        let selection = self.relative_selection();
 
-        let mut txt = Vec::new();
-        for (idx, e) in self.items.items.iter().enumerate() {
-            let tag = if let Some(tags) = self.tags.get(&e.hash) {
-                Some(tags.join(" "))
-            } else {
-                None
-            };
-            Self::add_entry(e, idx == selection, &mut txt, tag);
-        }
+        self.scroll_top = calc_scroll_top(
+            self.scroll_top,
+            height_in_lines,
+            selection,
+        );
 
         let title = format!(
             "commit {}/{}",
-            self.selection, self.selection_max
+            self.count_total.saturating_sub(self.selection),
+            self.count_total,
         );
 
         f.render_widget(
             Paragraph::new(
-                txt.iter()
-                    .skip(min * ELEMENTS_PER_LINE)
-                    .take(height * ELEMENTS_PER_LINE),
+                self.get_text()
+                    .iter()
+                    .skip(self.scroll_top * ELEMENTS_PER_LINE)
+                    .take(height_in_lines * ELEMENTS_PER_LINE),
             )
             .block(
                 Block::default()
