@@ -8,6 +8,7 @@ use crate::{
     keys,
     queue::Queue,
     strings,
+    ui::style::Theme,
 };
 use asyncgit::{
     current_tick, AsyncDiff, AsyncNotification, AsyncStatus,
@@ -99,6 +100,7 @@ impl Status {
     pub fn new(
         sender: &Sender<AsyncNotification>,
         queue: &Queue,
+        theme: &Theme,
     ) -> Self {
         Self {
             visible: true,
@@ -109,14 +111,16 @@ impl Status {
                 true,
                 true,
                 queue.clone(),
+                theme,
             ),
             index: ChangesComponent::new(
                 strings::TITLE_INDEX,
                 false,
                 false,
                 queue.clone(),
+                theme,
             ),
-            diff: DiffComponent::new(queue.clone()),
+            diff: DiffComponent::new(queue.clone(), theme),
             git_diff: AsyncDiff::new(sender.clone()),
             git_status: AsyncStatus::new(sender.clone()),
         }
@@ -246,59 +250,61 @@ impl Component for Status {
         out: &mut Vec<CommandInfo>,
         force_all: bool,
     ) -> CommandBlocking {
-        for c in self.components() {
-            if c.commands(out, force_all)
-                != CommandBlocking::PassingOn
-                && !force_all
-            {
-                break;
+        if self.visible {
+            for c in self.components() {
+                if c.commands(out, force_all)
+                    != CommandBlocking::PassingOn
+                    && !force_all
+                {
+                    break;
+                }
             }
+
+            {
+                let focus_on_diff = self.focus == Focus::Diff;
+                out.push(CommandInfo::new(
+                    commands::STATUS_FOCUS_LEFT,
+                    true,
+                    (self.visible && focus_on_diff) || force_all,
+                ));
+                out.push(CommandInfo::new(
+                    commands::STATUS_FOCUS_RIGHT,
+                    self.can_focus_diff(),
+                    (self.visible && !focus_on_diff) || force_all,
+                ));
+            }
+
+            out.push(
+                CommandInfo::new(
+                    commands::SELECT_STATUS,
+                    true,
+                    (self.visible && self.focus == Focus::Diff)
+                        || force_all,
+                )
+                .hidden(),
+            );
+
+            out.push(
+                CommandInfo::new(
+                    commands::SELECT_STAGING,
+                    true,
+                    (self.visible && self.focus == Focus::WorkDir)
+                        || force_all,
+                )
+                .order(-2),
+            );
+
+            out.push(
+                CommandInfo::new(
+                    commands::SELECT_UNSTAGED,
+                    true,
+                    (self.visible && self.focus == Focus::Stage)
+                        || force_all,
+                )
+                .order(-2),
+            );
         }
 
-        {
-            let focus_on_diff = self.focus == Focus::Diff;
-            out.push(CommandInfo::new(
-                commands::STATUS_FOCUS_LEFT,
-                true,
-                (self.visible && focus_on_diff) || force_all,
-            ));
-            out.push(CommandInfo::new(
-                commands::STATUS_FOCUS_RIGHT,
-                self.can_focus_diff(),
-                (self.visible && !focus_on_diff) || force_all,
-            ));
-        }
-
-        out.push(
-            CommandInfo::new(
-                commands::SELECT_STATUS,
-                true,
-                (self.visible && self.focus == Focus::Diff)
-                    || force_all,
-            )
-            .hidden(),
-        );
-
-        out.push(
-            CommandInfo::new(
-                commands::SELECT_STAGING,
-                true,
-                (self.visible && self.focus == Focus::WorkDir)
-                    || force_all,
-            )
-            .order(-2),
-        );
-
-        out.push(
-            CommandInfo::new(
-                commands::SELECT_UNSTAGED,
-                true,
-                (self.visible && self.focus == Focus::Stage)
-                    || force_all,
-            )
-            .order(-2),
-        );
-
         if self.visible {
             CommandBlocking::Blocking
         } else {
